﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Infragistics.Windows.DataPresenter;
using System.Data;
using System.Collections.ObjectModel;
using System.ComponentModel;
using Infragistics.Windows.DataPresenter.Events;
using System.Windows.Interactivity;

namespace DataGridDataRow
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public DataTable dt { get; set; }

        public MainWindow()
        {
            InitializeComponent();
            this.DataContext = new ViewModel();
        }
    }

    public class ViewModel : INotifyPropertyChanged
    {
        public ViewModel()
        {
            GridData = new ObservableCollection<Data>();
            GridData = Data.GetData(30, 1, 100);
        }
        public void XamDataGridCellUpdated(object sender, CellUpdatedEventArgs e)
        {
            e.Cell.Tag = true;
        }

        private ObservableCollection<Data> _gridData;
        public ObservableCollection<Data> GridData
        {
            get { return _gridData; }
            set
            {
                _gridData = value;
                PropChanged("GridData");
            }
        }

        public event PropertyChangedEventHandler PropertyChanged;
        public void PropChanged(string name)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(name));
        }
    }

    public class Data : INotifyPropertyChanged
    {
        private int high;
        private double? value;
        private string label;

        public string Label
        {
            get { return label; }
            set
            {
                label = value;
                PropChanged("Label");
            }
        }

        public int High
        {
            get { return high; }
            set
            {
                high = value;
                PropChanged("High");
            }
        }

        public double? Value
        {
            get { return value; }
            set
            {
                this.value = value;
                PropChanged("Value");
            }
        }

        public static ObservableCollection<Data> GetData(int points, int rangeStart, int rangeEnd)
        {
            ObservableCollection<Data> data = new ObservableCollection<Data>();
            Random r = new Random();
            for (int i = 0; i < points; i++)
            {
                data.Add(new Data
                {
                    Label = "Item " + i,
                    High = r.Next(rangeStart, rangeEnd),
                    value = (i % 2 == 0) ? (double)i : 0.0
                });
            }

            return data;
        }

        public event PropertyChangedEventHandler PropertyChanged;

        public void PropChanged(string name)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(name));
        }
    }

    public class FieldRecordToCellConverter : IMultiValueConverter
    {
        #region IMultiValueConverter Members

        public object Convert(object[] values, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            if (values.Length != 2)
                return Binding.DoNothing;

            Field fld = values[0] as Field;
            DataRecord rcd = values[1] as DataRecord;

            if (null == fld || null == rcd)
                return Binding.DoNothing;

            return rcd.Cells[fld];
        }

        public object[] ConvertBack(object value, Type[] targetTypes, object parameter, System.Globalization.CultureInfo culture)
        {
            Cell cell = value as Cell;

            if (null == cell)
                return null;

            return new object[] { cell.Field, cell.Record };
        }

        #endregion
    }

    public class CvpBackgroundBrushConverter : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            if (value is bool && (bool)value)
            {
                return true;
            }
            else
            {
                return false;
            }
        }

        public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            throw new NotImplementedException();
        }
    }
    public class XamDataGridBehaviorEx : Behavior<XamDataGrid>
    {
        #region Overrides

        protected override void OnAttached()
        {
            base.OnAttached();
            AssociatedObject.CellUpdated += AssociatedObject_CellUpdated;        }       
        protected override void OnDetaching()
        {
            base.OnDetaching();
            AssociatedObject.CellUpdated -= AssociatedObject_CellUpdated;
        }

        #endregion

        #region Events
        private void AssociatedObject_CellUpdated(object sender, CellUpdatedEventArgs e)
        {
            e.Cell.Tag = true;
        }

        #endregion

        #region Props

        public ICommand Command
        {
            get { return (ICommand)GetValue(CommandProperty); }
            set { SetValue(CommandProperty, value); }
        }

        // Using a DependencyProperty as the backing store for Command.  This enables 
        //animation, styling, binding, etc...
        public static readonly DependencyProperty CommandProperty =
            DependencyProperty.Register("Command", typeof(ICommand),
            typeof(XamDataGridBehaviorEx), new PropertyMetadata(null));

        #endregion

    }
}
